@@ -1,3 +1,3 @@
-from .credit_scoring import *
+from .loans_ru import *
 from .credit_scoring_1c import *
 from .score import *
